California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 006 - ELIMINATES CERTAIN ROAD REPAIR AND TRANSPORTATION FUNDING. REQUIRES CERTAIN FUEL TAXES AND VEHICLE FEES BE APPROVED BY THE ELECTORATE. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1407762 | SOUTHERN CALIFORNIA CONTRACTORS ASSOCIATION (NON-PROFIT 501 (C) (6)), NO ON PROP 6: STOP THE ATTACK ON BRIDGE & ROAD SAFETY | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1415769 | COMMITTEE TO SUPPORT PUBLIC TRANSIT IN THE BAY AREA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1219354 | NORTHERN CALIFORNIA CARPENTERS REGIONAL COUNCIL ISSUES PAC | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1374847 | LOW BALLOT MEASURE COMMITTEE; COMMITTEE TO INNOVATE FOR CALIFORNIA'S FUTURE, EVAN | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
971783 | CALIFORNIA CONFERENCE BOARD, AMALGAMATED TRANSIT UNION ISSUES COMMITTEE - NO ON PROP 6 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
970230 | ASSOCIATED GENERAL CONTRACTORS ISSUES PAC, VOTE NO ON PROP 6 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1400623 | VOTE YES ON PROP 6, COMMITTEE MAJOR FUNDING FROM HOWARD JARVIS TAXPAYERS ASSOCIATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1411097 | ASSOCIATED GENERAL CONTRACTORS OF CALIFORNIA, INC. (NONPROFIT 501 (C) (6) ) NO ON PROP 6 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1398829 | YES ON PROP 6, REPEAL THE GAS TAX | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1400937 | NO ON PROP 6: STOP THE ATTACK ON BRIDGE & ROAD SAFETY, SPONSORED BY BUSINESS, LABOR, LOCAL GOVERNMENTS AND TRANSPORTATION ADVOCATES | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1268914 | REFORM CALIFORNIA - YES ON 6 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1409207 | AMERICAN COUNCIL OF ENGINEERING COMPANIES, NO ON PROP 6 (NONPROFIT 501(C)(6)) | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1401950 | VOTER PROTECTION ALLIANCE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1317558 | CONSTRUCTION EMPLOYERS' ASSOCIATION PAC - ISSUES, SPONSORING NO ON PROP. 6: STOP THE ATTACK ON BRIDGE & ROAD SAFETY | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1412885 | TRANSFORMCA COMMITTEE FOR SUSTAINABLE, EQUITABLE TRANSPORTATION FUNDING TO OPPOSE PROPOSITION 6 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1407058 | LEAGUE OF CALIFORNIA CITIES (NONPROFIT (IRC 115) - NON-PUBLIC FUNDS, NO ON PROP 6 | OPPOSE